#define BASEVERSION "030"
#define BASEDATE "20030710"

/*
 * agidata.h
 *
 * - AGI game version database for aginfo.c
 *
 * Author: Paul David Doherty <agi@pdd.de>
 *
 * 000:   7 Jul 1999  first version (beta)
 * 001:  18 Jul 1999  first non-beta version
 * 002:  17 Aug 1999  synchronized with Sarien 0.4.7
 * 003:  22 Sep 1999  more versions
 * 004:  25 Nov 1999  more versions
 * 005:  25 Nov 1999  more versions (argh... uploaded the other one)
 * 006:  ???    1999  more versions; checked against Sarien 0.4.9
 * 007:   8 May 2001  more homemade versions
 * 008:  28 Nov 2001  still more homemade versions; 1 new interpreter
 * 009:   8 Mar 2002  new PQ1 version (thx to Antti Leimi)
 * 010:  28 Mar 2002  7 new versions (thx to Antti Leimi & Stefan
 *                    Meier); checked against Sarien 0.7.0
 * 011:  29 Mar 2002  small cleanups
 * 012:  31 Mar 2002  more fan-fic added; checked against NAGI 2.0.6
 * 013:  17 Sep 2002  two dozen more fan-fic added
 * 014:  24 Sep 2002  checked against sarien.cfg 1.22 (Sarien 0.80pre)
 * 015:  25 Sep 2002  some cleanups
 * 016:  26 Sep 2002  VOL checksums added to database
 * 017:  27 Sep 2002  new versions (thx to Keith Gersen & Vasyl
 *                    Tsvirkunov); added new status byte
 * 018:   3 Oct 2002  new version (thx to Keith Gersen); new database
 *                    format (to shut up gcc -c -Wall)
 * 019:  19 Oct 2002  new versions; some cleanups
 * 020:   3 Nov 2002  new versions
 * 021:  20 Nov 2002  new version (thx to Mark); checked against
 *                    sarien.cfg 1.23 (Sarien 0.80cvs)
 * 022:  25 Nov 2002  new versions
 * 023:   1 Dec 2002  many new versions (thx to Hugues Valois; Magnus
 *                    Kristiansen; Mark)
 * 024:   3 Dec 2002  new version
 * 025:  10 Dec 2002  demos renumbered again; "Tandy demo" removed;
 *                    interpreters added
 * 026:  31 Dec 2002  new versions (thx to Scott Worley)
 * 027:   3 Jan 2003  new versions (thx to Justin the Almighty)
 * 028:   2 Feb 2003  new version (thx to The Maur)
 * 029:   7 Jul 2003  new versions (fan-fic only)
 * 030:  10 Jul 2003  new versions (thx to Claudio Matsuoka)
 */
/* *INDENT-OFF* */

struct intfiles
{
  type8 platform;
  char *platformname;
  char *filename;
}
int_files[] =
{
  { 1, "MS-DOS", "agidata.ovl" },
  { 2, "Tandy CoCo3", "MnLn" },
  { 3, "Atari ST", "sierra.prg" },
  { 3, "Atari ST", "duck.dat" },
  { 4, "Apple IIgs", "demo.sys" },
  { 4, "Apple IIgs", "kq.sys" },
  { 4, "Apple IIgs", "kq2.sys" },
  { 4, "Apple IIgs", "kq3.sys" },
  { 4, "Apple IIgs", "kq4.sys" },
  { 4, "Apple IIgs", "ll.sys" },
  { 4, "Apple IIgs", "mg.sys" },
  { 4, "Apple IIgs", "mh.sys" },
  { 4, "Apple IIgs", "sq2.sys" },

  { 0, "*", "*" }
};

struct intbase
{
  type8 platform;		/* 1 = PC
				 * 2 = Tandy CoCo3
				 * 3 = Atari ST
				 * 4 = Apple IIgs */
  char *interp;
  type16 crcvalue;
  type16 int_id;
}
int_table[] =
{
  { 1, "2.089", 0x7b58, 0x2089 },

  { 1, "2.272", 0x6806, 0x2272 },

  { 1, "2.411", 0x863d, 0x2411 },
  { 1, "2.425", 0x9d3e, 0x2425 },
  { 1, "2.426", 0x92e0, 0x2426 },
  { 1, "2.435", 0xdf4c, 0x2435 },
  { 1, "2.439", 0x6dac, 0x2439 },
  { 1, "2.440", 0x6e29, 0x2440 },
  { 1, "2.440 (AGDS)", 0xf3e0, 0x2440 },

  { 1, "2.903", 0x31ee, 0x2903 },
  { 1, "2.911", 0xe64a, 0x2911 },
  { 1, "2.912", 0x0068, 0x2912 },
  { 1, "2.915", 0xe7f1, 0x2915 },
  { 1, "2.915 [corrupted]", 0xf9d0, 0xaaaa },

  { 1, "2.917", 0xb00c, 0x2917 },
  { 1, "2.917 (AGImouse 1.0/PAL)", 0x3bc9, 0x2917 },
  { 1, "2.917 (Mouse)", 0xe1f0, 0x2917 },

  { 1, "2.936", 0x0e1d, 0x2936 },
  { 1, "2.936 (AGImouse 0.6/256col)", 0x7a9f, 0x2936 },
  { 1, "2.936 (AGImouse 0.7/256col)", 0xc0f2, 0x2936 },

  { 1, "3.002.086", 0x9269, 0x3086 },

  { 1, "3.002.098", 0xe641, 0x3098 },
  { 1, "3.002.102", 0x74a6, 0x3102 },
  { 1, "3.002.107", 0x4a55, 0x3107 },
  { 1, "3.002.149", 0x408e, 0x3149 },

  { 2, "2.023", 0xaf95, 0x2023 },
  { 2, "2.072", 0x4c89, 0x2072 },

  { 3, "(v2) 2.00C", 0x1385, 0x2000 },
  { 3, "(v2) 1.115", 0xd435, 0x1115 },
  { 3, "(v2) 1.115 [cracked by Blowfly]", 0x3b41, 0x1115 },
  { 3, "(v2) 1.316 [cracked by STARMAN]", 0x3159, 0x1316 },
  { 3, "(v2) 1.397 [cracked by Magician]", 0xea9a, 0x2915 },
  { 3, "(v2) 1.422", 0xac4a, 0x2917 },
  { 3, "(v2) 1.422 [compressed]", 0x0e6b, 0x2917 },
  { 3, "(v2) 1.51 [cracked by ACE]", 0x8d76, 0x1510 },

  { 3, "(v3) 1.457 (a)", 0x7090, 0x1457 },
  { 3, "(v3) 1.457 (b)", 0xbe50, 0x1457 },
  { 3, "(v3) 1.485 [cracked by MCA]", 0x875d, 0x1485 },

  { 4, "(v2) 1.003", 0x2211, 0x1003 },
  { 4, "(v2) 1.005", 0xd8fe, 0x1005 },
  { 4, "(v2) 1.006", 0x55ae, 0x1006 },
  { 4, "(v2) 1.013 (a)", 0x0e86, 0x1013 },
  { 4, "(v2) 1.013 (b)", 0x2438, 0x1013 },
  { 4, "(v2) 1.014 (a)", 0xe42e, 0x1014 },
  { 4, "(v2) 1.014 (b)", 0xb157, 0x1014 },

  { 4, "(v3) 2.004", 0x847f, 0x2004 },
  { 4, "(v3) 2.006", 0x8bdc, 0x2006 },

  { 0, "*", 0x0000, 0x0000 }
};

struct dirbase
{
  type8 status;			/* 0 = end of list
				 * 1 = normal V3
				 * 2 = fan-made V3
				 * 3 = Amiga V3 */
  char *maindir;
  char *prefix;
}
dir_table[] =
{
  { 1, "bcdir", "bc" },
  { 1, "dmdir", "dm" },
  { 1, "grdir", "gr" },
  { 1, "kq3dir", "kq3" },
  { 1, "kq4dir", "kq4" },
  { 1, "mgdir", "mg" },
  { 1, "mhdir", "mh" },
  { 1, "mh2dir", "mh2" },
  { 1, "pq1dir", "pq1" },

  { 2, "vdir", "v" },
  /*
   * next one is hacked V with Sierra AGI (Chris Cromer)
   */
  { 2, "vgadir", "vga" },

  { 3, "dirs", "" },

  { 0, "*", "*" }
};


struct versionbase
{
  type8 agi_version;
  type16 crcvalue;		/* crc16 over struc files, agidata-internal */
  type32 df_check;		/* checksum (Sarien/Dark Fiber) */
  type16 volcrcvalue;		/* crc16 over all VOL files */
  type16 interp_match;		/* matching interpreter */
  type8 status;			/* 0 = original Sierra game
				 * 1 = fan-made game
				 * 2 = broken/hacked/cracked
				 * 3 = wanted */
  char *game;			/* game title and platform */
}
version_table[] =
{
/****************** SIERRA ORIGINALS ******************/

/*
 * Notes:
 * - (CE) in Apple IIgs versions stands for Carlos Escobar
 * - Chris Iden did the Atari ST and Tandy Coco3 ports
 */

/*
 * Note:
 * Older Sarien releases had a bug: when calculating checksums
 * for Amiga AGIv3 games, they didn't include the file DIRS in
 * the calculation. That's why sarien.cfg (i.e. v1.22) listed
 * Amiga AGIv3 games twice, once with the correct checksum
 * (like in the AGINFO database) and once with the other
 * checksum (leaving out DIRS).
 *
 * Game                                CHK/AGInfo   CHK/Sarien
 * -----------------------------------------------------------
 * Gold Rush (Amiga) 2.05 3/9/89         b3e1a        6effb
 * King's Quest 3 (Amiga) 2.15 11/15/89  84793        4ef1b
 * Manhunter 1: NY (Amiga) 1.06 3/18/89  4ba94        08950
 * Manhunter 2: SF (Amiga) 3.06 8/17/89  53d51        0904d
 * Mixed-Up Mother Goose (Amiga) 1.1     5cfb1        020d8
 * Police Quest 1 (Amiga) 2.0B 2/22/89   7f752        517cf
 */

/********************** ID: DEMO **********************/

  /*
   * The first demo features DDP, KQ3, SQ1, LSL1.
   * (Nick Sonneveld believes it to be an Apple demo, but I
   * doubt it.)
   */
  { 2, 0xc9f7, 0x484aa, 0xa1bc, 0x2425, 0,
    "AGI Demo 1 (IBM) 05/87" },

  /*
   * All versions of demo 2 are based on the same code, only
   * with some games left out for disk space or platform reasons.
   * The matrix looks like this:
   *                   SHC KQ2 KQ3 LSL1 MG PQ1 SQ1 SQ2 THX
   * Demo 2/3.5"        Y   Y   Y   Y   Y   Y   Y   Y   Y
   * Demo 2/5.25" [v1]  Y   N   N   Y   Y   Y   N   Y   Y
   * Demo 2/5.25" [v2]  Y   N   Y   Y   Y   Y   N   Y   N
   * Demo 2/GS          N   N   Y   Y   N   Y   Y   N   Y
   *
   * (SHC: Sierra's Helicopter Simulator; THX: Thexder)
   */

  { 2, 0x09bd, 0x8856c, 0x46db, 0x2915, 0,
    "AGI Demo 2 (IBM 3.5\") 11/87" },
  /*
   * In version 1, the KQ2 and KQ3 resources are still listed
   * in the DIRS (and VOLX therefore reports VOL.3 as missing).
   */
  { 2, 0x110b, 0x8cc43, 0x4f6a, 0x2915, 0,
    "AGI Demo 2 (IBM 5.25\") 11/87 [version 1]" },
  { 2, 0x725d, 0x843ac, 0xc0af, 0x2917, 0,
    "AGI Demo 2 (IBM 5.25\") 01/88 [version 2]" },
  /*
   * In the GS version of demo 2, PICTURE.125 (the babe picture
   * from LSL1) is censored -- i.e. you can't see her boobs
   * under water...
   */
  { 2, 0x6967, 0x93260, 0xc1b5, 0x0000, 0,
    "AGI Demo 2 (Apple IIgs) 1.0C" },

  /*
   * The sad story of the so-called "Tandy demo" seems to be this:
   * The Tandy 1000/IBM PCjr. emulator "Tand-em" came with a disk
   * image containing Demo 2/5.25"/version 1. Somebody tried and
   * failed in extracting the files from that image and uploaded
   * the (totally corrupted) results to Brian Provinciano's
   * "Ultimate AGI/SCI Site", where they still remain.
   *
   * In other words, there is no "Tandy demo".
   */
  { 2, 0xea3d, 0x4a057, 0xe06c, 0xaaaa, 2,
    "AGI Demo 2 (IBM 5.25\") 11/87 [version 1] [corrupted]" },

  /*
   * This demo features GR, MH2, MG, PQ1, SQ2 and LSL.
   */
  { 3, 0xbf28, 0x89592, 0x0665, 0x3102, 0,
    "AGI Demo 3 (IBM) 09/88" },

/********************** ID: BC ************************/

  { 2, 0x9ca6, 0x24a18, 0x5773, 0x2439, 0,
    "Black Cauldron (IBM) 2.00 6/14/87" },
  { 2, 0x31df, 0x25640, 0xdf94, 0x0000, 0,
    "Black Cauldron (Amiga) 2.00 6/14/87" },

  /*
   * 5.25" is just guessed
   */
  { 3, 0x9119, 0x22b50, 0x688a, 0x3098, 0,
    "Black Cauldron (IBM 5.25\") 2.10 11/10/88" },
  { 3, 0x2c61, 0x23e0e, 0x28bc, 0x3098, 0,
    "Black Cauldron (IBM 3.5\") 2.10 11/10/88" },

  { 3, 0x14a7, 0x285fb, 0x0e95, 0x0000, 0,
    "Black Cauldron (Apple IIgs) 1.0O 2/24/89 (CE)" },

/********************** ID: DUCK **********************/

  /*
   * IBM version (1.0Q 6/9/86) is AGI1/2 on booter -- can
   * this be extracted somehow?
   */

  /*
   * sarien.cfg incorrectly lists this as 1.0C
   */
  { 2, 0xec30, 0x1a7af, 0x02e6, 0x0000, 0,
    "Donald Duck's Playground (ST) 1.0A 8/8/86" },
  { 2, 0x4870, 0x1a831, 0x422d, 0x0000, 2,
    "Donald Duck's Playground (ST) 1.0A 8/8/86 [VOL.0->LOGIC.14 hacked]" },

  /*
   * sarien.cfg incorrectly lists this as ST version
   */
  { 2, 0x1d23, 0x1afba, 0x7435, 0x0000, 0,
    "Donald Duck's Playground (Amiga) 1.0C" },

/********************** ID: GR ************************/

  /*
   * The GR crack (both 3.5" and 5.25" version) simply replaces
   * LOGIC.129 (copy protection) with LOGIC.73 (intro), thereby
   * messing up some game settings.
   */
  { 3, 0x633f, 0xb5a25, 0x2edd, 0x3149, 0,
    "Gold Rush (IBM 5.25\") 2.01 12/22/88" },
  { 3, 0x98c7, 0xb598f, 0x2edd, 0x3149, 2,
    "Gold Rush (IBM 5.25\") 2.01 12/22/88 [DIR hacked]" },
  { 3, 0xb9e3, 0xb1c9e, 0x3ea7, 0x3149, 0,
    "Gold Rush (IBM 3.5\") 2.01 12/22/88" },
  { 3, 0x421b, 0xb1c08, 0x3ea7, 0x3149, 2,
    "Gold Rush (IBM 3.5\") 2.01 12/22/88 [DIR hacked]" },

  { 3, 0xd93d, 0xb68ab, 0xb047, 0x0000, 0,
    "Gold Rush (ST) 1.01 1/13/89 aka 2.01 12/22/88" },
  { 3, 0xd93d, 0xb68ab, 0x6582, 0x0000, 2,
    "Gold Rush (ST) 1.01 1/13/89 aka 2.01 12/22/88 [VOL.0 from disk 2]" },
  { 3, 0xd93d, 0xb68ab, 0x4b72, 0x0000, 2,
    "Gold Rush (ST) 1.01 1/13/89 aka 2.01 12/22/88 [VOL.3 missing]" },
  { 3, 0xd93d, 0xb68ab, 0x8104, 0x0000, 2,
    "Gold Rush (ST) 1.01 1/13/89 aka 2.01 12/22/88 [VOL.3 missing/VOL.0 from disk 2]" },

  { 3, 0xb502, 0xb6f67, 0x5987, 0x0000, 0,
    "Gold Rush (Apple IIgs) 1.0M 2/28/89 (CE) aka 2.01 12/22/88" },

  { 3, 0xfb22, 0xb3e1a, 0x7177, 0x0000, 0,
    "Gold Rush (Amiga) 1.01 1/13/89 aka 2.05 3/9/89" },

/********************** ID: KQ/KQ1 ********************/

  /*
   * WANTED!
   */
  { 2, 0x0000, 0x00000, 0x0000, 0x2272, 3,
    "King's Quest 1 (IBM) 1.0U" },
  { 2, 0xadfb, 0x49c6b, 0xe36b, 0x0000, 0,
    "King's Quest 1 (Amiga) 1.0U" },

  { 2, 0xb966, 0x4a079, 0xb85d, 0x0000, 0,
    "King's Quest 1 (ST) 1.0V" },

  { 2, 0x7a75, 0x4c02c, 0x6228, 0x0000, 0,
    "King's Quest 1 (Mac) 2.0C" },

  /*
   * 5.25" & 3.5" identical (confirmed by Hugues Valois)
   */
  { 2, 0x9844, 0x49eda, 0x79f2, 0x2425, 0,
    "King's Quest 1 (IBM 5.25\"/3.5\") 2.0F" },
  /*
   * same data, different interpreter (2425->2917)
   */
  { 2, 0x9844, 0x49eda, 0x79f2, 0x2917, 0,
    "King's Quest 1 (IBM 5.25\"/3.5\") 2.0F" },

  { 2, 0xd09c, 0x4a9e8, 0x0aef, 0x0000, 0,
    "King's Quest 1 (Apple IIgs) 1.0S-88223" },

/********************** ID: KQ2 ***********************/

  { 2, 0xbf73, 0x79d1b, 0xab34, 0x0000, 0,
    "King's Quest 2 (Apple IIgs) 2.0A 6/16/88 (CE)" },

  { 2, 0xb837, 0x5d395, 0x9550, 0x0000, 0,
    "King's Quest 2 (Amiga) 2.0J" },
  { 2, 0xb837, 0x5d395, 0xd74c, 0x0000, 2,
    "King's Quest 2 (Amiga) 2.0J [VOL.2 broken]" },
  { 2, 0x62ae, 0x5bce6, 0x9550, 0x0000, 2,
    "King's Quest 2 (Amiga) 2.0J [OBJECT decrypted]" },
  { 2, 0x62ae, 0x5bce6, 0xd74c, 0x0000, 2,
    "King's Quest 2 (Amiga) 2.0J [VOL.2 broken/OBJECT decrypted]" },
  { 2, 0x4caa, 0x5f4b9, 0x9550, 0x0000, 2,
    "King's Quest 2 (Amiga) 2.0J [OBJECT padded]" },
  { 2, 0x4caa, 0x5f4b9, 0xd74c, 0x0000, 2,
    "King's Quest 2 (Amiga) 2.0J [VOL.2 broken/OBJECT padded]" },

  { 2, 0x6c7c, 0x6382e, 0x78ae, 0x0000, 0,
    "King's Quest 2 (Mac) 2.0R" },

  /*
   * 5.25" & 3.5" identical (confirmed by Hugues Valois)
   */
  { 2, 0x010f, 0x633cb, 0x8f78, 0x2411, 0,
    "King's Quest 2 (IBM 5.25\"/3.5\") 2.1" },

  /*
   * 5.25" & 3.5" identical (confirmed by Hugues Valois)
   */
  { 2, 0x4deb, 0x63338, 0xe37c, 0x2426, 0,
    "King's Quest 2 (IBM 5.25\"/3.5\") 2.2" },
  /*
   * same data, different interpreter (2426->2917)
   */
  { 2, 0x4deb, 0x63338, 0xe37c, 0x2917, 0,
    "King's Quest 2 (IBM 5.25\"/3.5\") 2.2" },

/********************** ID: KQ3 ***********************/

  { 2, 0xdd4d, 0x88673, 0x03a9, 0x2272, 0,
    "King's Quest 3 (IBM) 1.01 11/08/86" },
  { 2, 0xe464, 0x888c1, 0xac11, 0x0000, 0,
    "King's Quest 3 (Amiga) 1.01 11/8/86" },
  { 2, 0x3446, 0x88934, 0xdeb2, 0x0000, 2,
    "King's Quest 3 (Amiga) 1.01 11/8/86 [cracked?]" },

  { 2, 0x1b2d, 0x882b7, 0x74da, 0x0000, 0,
    "King's Quest 3 (ST) 1.02 11/18/86" },

  /*
   * 3.5" & 5.25" is confirmed (Hugues Valois)
   */
  { 2, 0xa0b9, 0x840d3, 0x178a, 0x2435, 0,
    "King's Quest 3 (IBM 5.25\") 2.00 5/25/87" },
  { 2, 0xb648, 0x83191, 0x923c, 0x2435, 0,
    "King's Quest 3 (IBM 3.5\") 2.00 5/25/87" },

  /*
   * 5.25" is confirmed (Hugues Valois)
   */
  { 2, 0xa728, 0x8410b, 0x2932, 0x2936, 0,
    "King's Quest 3 (IBM 5.25\") 2.14 3/15/88" },
  { 2, 0xef1b, 0x83695, 0x3714, 0x2936, 0,
    "King's Quest 3 (IBM 3.5\") 2.14 3/15/88" },
  { 2, 0x4bc4, 0x8410b, 0xa9f6, 0x0000, 0,
    "King's Quest 3 (Mac) 2.14 3/15/88" },

  { 2, 0x2806, 0x7cbe8, 0xa33c, 0x0000, 0,
    "King's Quest 3 (Tandy CoCo3) 1.0C 6/27/88" },

  { 2, 0xbc09, 0x85cd4, 0xc3f2, 0x0000, 0,
    "King's Quest 3 (Apple IIgs) 2.0A 8/28/88 (CE)" },

  { 3, 0x1c20, 0x84793, 0x1eac, 0x0000, 0,
    "King's Quest 3 (Amiga) 2.15 11/15/89" },

/********************** ID: KQ4 ***********************/

  /*
   * WANTED! (only have partial of 5.25" version)
   */
  { 3, 0x9f9a, 0xb2f20, 0xffff, 0x3086, 3,
    "King's Quest 4 (IBM 5.25\") 2.0 7/27/88" },
  /*
   * 3.5" is confirmed (Hugues Valois)
   */
  { 3, 0x4ade, 0xb124b, 0x6836, 0x3086, 0,
    "King's Quest 4 (IBM 3.5\") 2.0 7/27/88" },
  { 3, 0x4ade, 0xb124b, 0xed5e, 0x3086, 2,
    "King's Quest 4 (IBM 3.5\") 2.0 7/27/88 [VOL.3 broken]" },

  /*
   * WANTED!
   */
  { 3, 0x0000, 0x00000, 0x0000, 0x3086, 3,
    "King's Quest 4 (IBM 5.25\") 2.2 9/27/88" },
  /*
   * 3.5" is just guessed
   */
  { 3, 0x4829, 0xb291f, 0xd28d, 0x3086, 0,
    "King's Quest 4 (IBM 3.5\") 2.2 9/27/88" },

  /*
   * version 2.3 has the same date but is different from 2.2
   * (some LOGICs changed, LOGIC.152 removed)
   */
  { 3, 0xb525, 0xb3722, 0xf4d5, 0x3086, 0,
    "King's Quest 4 (IBM 5.25\") 2.3 9/27/88" },
  /*
   * WANTED!
   */
  { 3, 0x0000, 0x00000, 0x0000, 0x3086, 3,
    "King's Quest 4 (IBM 3.5\") 2.3 9/27/88" },

  { 3, 0x9fc9, 0xaf778, 0x6a44, 0x0000, 0,
    "King's Quest 4 (Apple IIgs) 1.0K 11/22/88 (CE)" },

/********************** ID: DM ************************/

  { 3, 0x8000, 0x9cb15, 0xb350, 0x3102, 0,
    "King's Quest 4 demo (IBM)" },

/********************** ID: LLLLL *********************/

  /*
   * 5.25" & 3.5" identical (confirmed by Hugues Valois)
   */
  { 2, 0x86ec, 0x6f5e1, 0x12da, 0x2440, 0,
    "Leisure Suit Larry 1 (IBM 5.25\"/3.5\") 1.00 6/1/87" },
  { 2, 0x86ec, 0x6f5e1, 0x6b81, 0x2440, 2,
    "Leisure Suit Larry 1 (IBM 5.25\"/3.5\") 1.00 6/1/87 [VOL.2->VIEW.17 broken]" },
  { 2, 0xba6e, 0x6f5e1, 0xc5fd, 0x2440, 2,
    "Leisure Suit Larry 1 (IBM 5.25\"/3.5\") 1.00 6/1/87 [corrupt/padded]" },
  /*
   * next one seems to exist but I don't have it
   */
/*
  { 2, 0x86ec, 0x6f5e1, 0x12da, 0x2917, 0,
    "Leisure Suit Larry 1 (IBM 5.25\"/3.5\") 1.00 6/1/87" },
*/

  { 2, 0x1959, 0x6f7e1, 0xb616, 0x0000, 0,
    "Leisure Suit Larry 1 (ST) 1.04 6/18/87" },

  { 2, 0x3147, 0x78202, 0xc765, 0x0000, 0,
    "Leisure Suit Larry 1 (Mac) 1.05 6/26/87" },
  { 2, 0x868e, 0x6fddb, 0x6b33, 0x0000, 0,
    "Leisure Suit Larry 1 (Amiga) 1.05 6/26/87" },
  { 2, 0x868e, 0x6fddb, 0x9845, 0x0000, 2,
    "Leisure Suit Larry 1 (Amiga) 1.05 6/26/87 [VOL.2 missing]" },

  { 2, 0x6763, 0x6e41e, 0xf937, 0x0000, 0,
    "Leisure Suit Larry 1 (Apple IIgs) 1.0E" },
  { 2, 0x6763, 0x6e41e, 0xf0fe, 0x0000, 2,
    "Leisure Suit Larry 1 (Apple IIgs) 1.0E [VOL.2->VIEW.178 broken]" },

  /*
   * FORMAT PROBLEM: resources are in strange format
   *
   * This version is weird: all the resources seem to have a format
   * that is completely different from all other AGI games. Maybe
   * some form of encryption?
   */
  { 2, 0xc571, 0x70d35, 0xf019, 0x0000, 0,
    "Leisure Suit Larry 1 (Tandy CoCo3)" },

/********************** ID: MH ************************/

  /*
   * loads of broken versions of the ST one...
   */
  { 3, 0xbbe0, 0x4ce19, 0x6ad4, 0x0000, 0,
    "Manhunter 1: NY (ST) 1.03 10/20/88" },
  { 3, 0xbbe0, 0x4ce19, 0xcc2a, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [VOL.2/10 broken]" },
  { 3, 0xbbe0, 0x4ce19, 0x3e8b, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [VOL.10 broken]" },
  { 3, 0xbbe0, 0x4ce19, 0x6f4b, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [VOL.11/12 broken]" },
  { 3, 0xbbe0, 0x4ce19, 0xc9b5, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [VOL.2/10/11/12 broken]" },
  { 3, 0xe719, 0x4f7b7, 0x6ad4, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [OBJ decrypted]" },
  { 3, 0xe719, 0x4f7b7, 0xcc2a, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [OBJ decrypted/VOL.2/10 broken]" },
  { 3, 0xe719, 0x4f7b7, 0x3e8b, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [OBJ decrypted/VOL.10 broken]" },
  { 3, 0xe719, 0x4f7b7, 0x6f4b, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [OBJ decrypted/VOL.11/12 broken]" },
  { 3, 0xe719, 0x4f7b7, 0xc9b5, 0x0000, 2,
    "Manhunter 1: NY (ST) 1.03 10/20/88 [OBJ decrypted/VOL.2/10/11/12 broken]" },

  { 3, 0x321b, 0x4ba94, 0xc90f, 0x0000, 0,
    "Manhunter 1: NY (Amiga) 1.06 3/18/89" },

  /*
   * date listed incorrectly as 8/30/88 in AGI Specs
   */

  { 3, 0x8b20, 0x4c16d, 0x6b91, 0x3102, 0,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88" },
  { 3, 0x8b20, 0x4c16d, 0x4208, 0x3102, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.1->LOGIC.159 reconstructed]" },
  { 3, 0x8b20, 0x4c16d, 0xcff4, 0x3102, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.1->LOGIC.159 hacked]" },
  { 3, 0x8b20, 0x4c16d, 0xad28, 0x3102, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.3/4/5/11 missing]" },
  /*
   * same data, different interpreter (3102->3107)
   */
  { 3, 0x8b20, 0x4c16d, 0x6b91, 0x3107, 0,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88" },
  { 3, 0x8b20, 0x4c16d, 0x4208, 0x3107, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.1->LOGIC.159 reconstructed]" },
  { 3, 0x8b20, 0x4c16d, 0xcff4, 0x3107, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.1->LOGIC.159 hacked]" },
  { 3, 0x8b20, 0x4c16d, 0xad28, 0x3107, 2,
    "Manhunter 1: NY (IBM 5.25\") 1.22 8/31/88 [VOL.3/4/5/11 missing]" },
  /*
   * don't have 3.5" with interpreter 3102 but it must exist since
   * there is a 5.25" version of it
   */
  { 3, 0xaa8d, 0x49687, 0x9c00, 0x3102, 0,
    "Manhunter 1: NY (IBM 3.5\") 1.22 8/31/88" },
  { 3, 0xaa8d, 0x49687, 0xad91, 0x3102, 2,
    "Manhunter 1: NY (IBM 3.5\") 1.22 8/31/88 [VOL.1->LOGIC.159 hacked]" },
  /*
   * same data, different interpreter (3102->3107)
   */
  { 3, 0xaa8d, 0x49687, 0x9c00, 0x3107, 0,
    "Manhunter 1: NY (IBM 3.5\") 1.22 8/31/88" },
  { 3, 0xaa8d, 0x49687, 0xad91, 0x3107, 2,
    "Manhunter 1: NY (IBM 3.5\") 1.22 8/31/88 [VOL.1->LOGIC.159 hacked]" },

  { 3, 0x8759, 0x4c705, 0xb70a, 0x0000, 0,
    "Manhunter 1: NY (Apple IIgs) 2.0E 10/05/88 (CE)" },

/********************** ID: MH2 ***********************/

  { 3, 0xb48d, 0x5360b, 0x6a96, 0x0000, 0,
    "Manhunter 2: SF (ST) 1.0 7/29/89" },
  /*
   * corrupt VOL.0 is on disk 1, correct one on disk 2 & 3... why?
   */
  { 3, 0xb48d, 0x5360b, 0x46a3, 0x0000, 2,
    "Manhunter 2: SF (ST) 1.0 7/29/89 [VOL.0->PICTURE.110 broken]" },
  { 3, 0xb48d, 0x5360b, 0x0558, 0x0000, 2,
    "Manhunter 2: SF (ST) 1.0 7/29/89 [VOL.2/3/9 missing]" },

  /*
   * WANTED!
   */
  { 3, 0x0000, 0x00000, 0x0000, 0x3149, 3,
    "Manhunter 2: SF (IBM 5.25\") 3.02 7/26/89" },
  /*
   * 3.5" is just guessed
   */
  { 3, 0xfc02, 0x53971, 0xd67d, 0x3149, 0,
    "Manhunter 2: SF (IBM 3.5\") 3.02 7/26/89" },

  { 3, 0x2df0, 0x584f9, 0x3b4d, 0x3149, 0,
    "Manhunter 2: SF (IBM 5.25\") 3.03 8/17/89" },
  /*
   * WANTED!
   */
  { 3, 0x0000, 0x00000, 0x0000, 0x3149, 3,
    "Manhunter 2: SF (IBM 3.5\") 3.03 8/17/89" },

  { 3, 0x6974, 0x53d51, 0x2300, 0x0000, 0,
    "Manhunter 2: SF (Amiga) 3.06 8/17/89" },

  /*
   * WANTED! (was this really released?)
   */
  { 3, 0x0000, 0x00000, 0x0000, 0x0000, 3,
    "Manhunter 2: SF (Apple IIgs)" },

/********************** ID: MG ************************/

  /*
   * this should be 3.5" version -- is there a 5.25" version
   * too?
   */
  { 2, 0x86f5, 0x5d77c, 0x79e4, 0x2915, 0,
    "Mixed-Up Mother Goose (IBM)" },
  /*
   * NAGI incorrectly(?) lists other version as corrupt
   */
  { 2, 0xe305, 0x5d7c6, 0x79e4, 0x2915, 2,
    "Mixed-Up Mother Goose (IBM) [corrupt/OBJECT from disk 1]" },

  { 2, 0xbc6a, 0x5f4e8, 0xc9f9, 0x0000, 0,
    "Mixed-Up Mother Goose (Apple IIgs)" },

  { 3, 0x493e, 0x5cfb1, 0xe2a8, 0x0000, 0,
    "Mixed-Up Mother Goose (Amiga) 1.1" },

/********************** ID: PQ ************************/

  /*
   * this should be 5.25" version -- is there a 3.5" version
   * too? I doubt it
   */
  { 2, 0xc39b, 0x7f18b, 0x4409, 0x2903, 0,
    "Police Quest 1 (IBM) 2.0A 10/23/87" },
  /*
   * same data, different interpreter
   */
  { 2, 0xc39b, 0x7f18b, 0x4409, 0x2911, 0,
    "Police Quest 1 (IBM) 2.0A 10/23/87" },

  /*
   * this should be 5.25" version -- is there a 3.5" version
   * too? I doubt it
   */
  { 2, 0xff4b, 0x7ef35, 0xad5d, 0x2915, 0,
    "Police Quest 1 (IBM) 2.0E 11/17/87" },

  /*
   * 5.25" is just guessed
   */
  { 2, 0x8733, 0x7ef06, 0x92f3, 0x2917, 0,
    "Police Quest 1 (IBM 5.25\"/ST) 2.0G 12/03/87" },
  { 2, 0x8733, 0x7ef06, 0xd26e, 0x2917, 2,
    "Police Quest 1 (IBM 5.25\"/ST) 2.0G 12/03/87 [VOL.3 broken]" },
  { 2, 0x8733, 0x7ef06, 0x6277, 0x2917, 2,
    "Police Quest 1 (IBM 5.25\"/ST) 2.0G 12/03/87 [VOLs corrupt]" },
  /*
   * 3.5" is confirmed (Hugues Valois)
   */
  { 2, 0x3dc1, 0x7e0bc, 0x3f25, 0x2917, 0,
    "Police Quest 1 (IBM 3.5\") 2.0G 12/03/87" },
  { 2, 0xf49b, 0x7ef06, 0xa5b9, 0x0000, 0,
    "Police Quest 1 (Mac) 2.0G 12/3/87" },

  { 2, 0xebee, 0x7db3f, 0xe46e, 0x0000, 0,
    "Police Quest 1 (Apple IIgs) 2.0A-88318" },
  { 2, 0x0249, 0x7dbe5, 0x0555, 0x0000, 0,
    "Police Quest 1 (Apple IIgs) 2.0B-88421" },

  { 3, 0x6507, 0x7f752, 0x8984, 0x0000, 0,
    "Police Quest 1 (Amiga) 2.0B 2/22/89" },

/********************** ID: SQ ************************/

  /*
   * weirdly enough the *only* difference between 1.0 and 1.0X
   * is the version number (in LOGIC.67). File date on 1.0 is
   * 13/6/86, on 1.0X 24/9/86
   */
  { 2, 0x4005, 0x67fcc, 0xa620, 0x2089, 0,
    "Space Quest 1 (IBM) 1.0" },
  { 2, 0xe16c, 0x68049, 0xa620, 0x2089, 2,
    "Space Quest 1 (IBM) 1.0 [LOGDIR broken]" },

  { 2, 0x1230, 0x68036, 0xea36, 0x2089, 0,
    "Space Quest 1 (IBM) 1.0X" },
  { 2, 0x1230, 0x68036, 0x6283, 0x2089, 2,
    "Space Quest 1 (IBM) 1.0X [VOL.2->VIEW.184 broken]" },

  { 2, 0xf754, 0x67f6e, 0xbe83, 0x2272, 0,
    "Space Quest 1 (IBM) 1.1A" },
  { 2, 0x8cde, 0x69597, 0xa7da, 0x0000, 0,
    "Space Quest 1 (ST) 1.1A" },

  { 2, 0x0502, 0x696dd, 0x1ea0, 0x0000, 0,
    "Space Quest 1 (Amiga) 1.2" },

  { 2, 0xe064, 0x6a277, 0x2f0e, 0x0000, 0,
    "Space Quest 1 (Mac) 1.5D" },

  /*
   * 5.25" & 3.5" identical (confirmed by Hugues Valois)
   */
  { 2, 0x4d2f, 0x68244, 0x57e7, 0x2426, 0,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2" },
  { 2, 0x4d2f, 0x68244, 0xb685, 0x2426, 2,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2 [VOL.0->LOGIC.13 broken]" },
  /*
   * same data, different interpreter (2426->2917)
   */
  { 2, 0x4d2f, 0x68244, 0x57e7, 0x2917, 0,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2" },
  { 2, 0x4d2f, 0x68244, 0xb685, 0x2917, 2,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2 [VOL.0->LOGIC.13 broken]" },
  { 2, 0xe0ea, 0x68555, 0x57e7, 0x2917, 2,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2 [WORDS.TOK hacked]" },
  { 2, 0xe0ea, 0x68555, 0xb685, 0x2917, 2,
    "Space Quest 1 (IBM 5.25\"/3.5\") 2.2 [VOL.0->LOGIC.13 broken/WORDS.TOK hacked]" },

  { 2, 0xa06f, 0x69ec0, 0xe45e, 0x0000, 0,
    "Space Quest 1 (Apple IIgs) 2.2" },

/********************** ID: SQ2 ***********************/

  /*
   * 5.25" is just guessed
   */
  { 2, 0x0a1a, 0x8db32, 0xea8d, 0x2912, 0,
    "Space Quest 2 (IBM 5.25\") 2.0A" },
  /*
   * 3.5" is just guessed
   */
  { 2, 0xd589, 0x8d825, 0x2de8, 0x2912, 0,
    "Space Quest 2 (IBM 3.5\") 2.0A" },

  /*
   * 2.0C is weird: there are apparently 2 different versions of
   * this. The old one with interpreter 2915 has *loads* of
   * differences in the resources.
   * Unfortunately we only have one copy (abandonware) of the 5.25
   * version of 2915, a valid 3.5" of 2917 and an apparently broken
   * 5.25" of 2917 (abandonware again).
   * This needs research!
   */
  { 2, 0x3c7c, 0x8da3e, 0x74d6, 0x2915, 0,
    "Space Quest 2 (IBM 5.25\"/ST) 2.0C [A]" },
  /*
   * or could this be a patch or ST peculiarity?
   */
  { 2, 0x3c7c, 0x8da3e, 0xb2c0, 0x2915, 2,
    "Space Quest 2 (IBM 5.25\"/ST) 2.0C [A] [VOL.1/3->LOGIC.86 broken]" },
  { 2, 0x3c7c, 0x8da3e, 0x9557, 0x2915, 2,
    "Space Quest 2 (IBM 5.25\"/ST) 2.0C [A] [VOLs corrupt]" },
  { 2, 0x0000, 0x00000, 0x0000, 0x2915, 3,
    "Space Quest 2 (IBM 3.5\") 2.0C [A]" },

  /*
   * different (!) data, different interpreter (2915->2917)
   */
  { 2, 0x0000, 0x00000, 0x0000, 0x2917, 3,
    "Space Quest 2 (IBM 5.25\") 2.0C [B]" },
  /*
   * The DIR files seem to be broken (or at least padded with
   * garbage) -- they reference VOL.4 and VOL.8.
   */
  { 2, 0x43d4, 0x8e5c7, 0xa2da, 0x2917, 2,
    "Space Quest 2 (IBM 5.25\") 2.0C [B] [broken]" },
  { 2, 0x3749, 0x8e6a7, 0xed21, 0x2917, 0,
    "Space Quest 2 (IBM 3.5\") 2.0C [B]" },

  { 2, 0x37ee, 0x8df84, 0x72e9, 0x2936, 0,
    "Space Quest 2 (IBM 5.25\") 2.0D" },
  { 2, 0xd1d0, 0x8de46, 0x9a3a, 0x2936, 0,
    "Space Quest 2 (IBM 3.5\") 2.0D" },
  { 2, 0x527e, 0x8df84, 0x471a, 0x0000, 0,
    "Space Quest 2 (Mac) 2.0D" },

  { 2, 0xb29e, 0x8e310, 0x44f9, 0x2936, 0,
    "Space Quest 2 (IBM 5.25\") 2.0F" },
  { 2, 0x79ac, 0x8e29b, 0xb88d, 0x2936, 0,
    "Space Quest 2 (IBM 3.5\") 2.0F" },
  /*
   * only difference to IBM 3.5"/2.0F: OBJECT file
   */
  { 2, 0xd77e, 0x8fea6, 0xb88d, 0x0000, 0,
    "Space Quest 2 (Amiga) 2.0F" },
  { 2, 0xd77e, 0x8fea6, 0x320c, 0x0000, 2,
    "Space Quest 2 (Amiga) 2.0F [VOL.2->PICTURE.16 broken]" },

  { 2, 0xe5da, 0x8e983, 0xd3d3, 0x0000, 0,
    "Space Quest 2 (Apple IIgs) 2.0A 7/25/88 (CE)" },

  { 2, 0x3090, 0x52774, 0xb4e2, 0x0000, 2,
    "Space Quest 2 (ST) 2.?? [corrupt/incomplete]" },

/********************** ID: XMAS **********************/

  /*
   * The only differences between the two versions are two small
   * fixes in LOGIC.0 and LOGIC.92. In both versions the DIR
   * files reference VOL.1 and VOL.2 but there is only VOL.0.
   */
  { 2, 0x643a, 0x31677, 0xffae, 0x2272, 0,
    "Xmas Card 1986 (IBM) [version 1]" },
  { 2, 0x643a, 0x31677, 0x24b5, 0x2272, 0,
    "Xmas Card 1986 (IBM) [version 2]" },


/******************** FAN-MADE AGIv2 ******************/

/*
 * missing fan-fic (listed in NAGI):
 *
 * ;; FAN MADE GAMES
 *
 * [dg]
 * name=DG v1.00 2001-10-31
 * ; 917
 * inherits=pc_buffbri
 * ; prime candiate for adding the mouse stuff for
 * id=DG
 * crc_object=0x014D1D73
 * crc_words=0x94B42919
 * crc_vol_0=0xE0E71938
 * crc_dir_log=0x8AC62EA4
 * crc_dir_pic=0xCEAD2B82
 * crc_dir_view=0x20A10FD0
 *
 * [disco1]
 * name=Disco Nights 2001-06-17
 * ; 917
 * inherits=pc_2_936
 * id=DISCO
 * crc_vol_0=0x48B882FB
 * crc_dir_log=0xD9A32E20
 * crc_dir_view=0x6112FC4C
 * crc_dir_pic=0x5F7D4EDC
 * crc_dir_snd=0x86B17B09
 * crc_object=0x3D97D1E4
 * crc_words=0x0C194EAA
 *   [NOTE: this one will be [B] in my count!]
 *
 * [hit]
 * name=Hitler's Legacy 2001-01-12
 * ; MOUSE GAME
 * inherits=pc_buffbri
 * id=HIT
 * crc_vol_0=0xE935114D
 * crc_dir_log=0x129F33FB
 * crc_dir_view=0x334E6CBC
 * crc_dir_pic=0xFFFF017C
 * crc_dir_snd=0x00000000
 * crc_object=0xB9050330
 * crc_words=0x48CCE405
 *
 * [jeff]
 * name=Jeff's Quest 0.5a 1998-05-31
 * inherits=pc_2_936
 * id=JEFF
 * crc_vol_1=0x14EBCECD
 * crc_vol_0=0x0F453007
 * crc_dir_log=0xEE8F6ED8
 * crc_dir_view=0xD16F3269
 * crc_dir_pic=0xA732A477
 * crc_dir_snd=0x06ED7A18
 * crc_object=0x13CF6BE6
 * crc_words=0x1116041C
 *
 * [lp4]
 * name=Lost Planet Progress 4 2001-01-09
 * inherits=pc_buffbri
 * id=LP
 * crc_vol_0=0xCF58EE0B
 * crc_dir_log=0xF8A6C23A
 * crc_dir_view=0x7B3B57E4
 * crc_dir_pic=0x03AFBBBF
 * crc_dir_snd=0x00000000
 * crc_object=0x142FAF23
 * crc_words=0x474DFEF6
 *
 * [pimp]
 * name=Pimp Quest 2001-02-10
 * inherits=pc_2_440
 * id=PIMP
 * crc_vol_0=0xF6E852A0
 * crc_dir_log=0x46D51A2F
 * crc_dir_view=0x75FCB21B
 * crc_dir_pic=0x29153CDA
 * crc_dir_snd=0x00000000
 * crc_object=0x95AC5ED7
 * crc_words=0xEA251D9F
 *
 * [pimp2]
 * name=Pimp Quest 2001-02-11
 * inherits=pc_2_440
 * id=PIMP
 * crc_vol_0=0x1ACE4E9A
 * crc_dir_log=0xB8BA0AB5
 * crc_dir_view=0xAC10B18F
 * crc_dir_pic=0x8935E0A5
 * crc_dir_snd=0x00000000
 * crc_object=0x1675AB7C
 * crc_words=0x0A174E84
 *
 * [sqm]
 * name=SQ Mouse Demo 2001-03-16
 * inherits=pc_buffbri
 * id=SQM
 * crc_vol_0=0x5376723F
 * crc_dir_log=0xCB354D78
 * crc_dir_view=0x91562469
 * crc_dir_pic=0xB22AD815
 * crc_dir_snd=0x3846126B
 * crc_object=0xCBE73F94
 * crc_words=0xB4343489
 *
 * [tlc]
 * name=Space Quest: The Lost Chapter 2001-02-04
 * inherits=pc_2_936
 * id=TLC
 * crc_vol_1=0x6717A246
 * crc_vol_0=0xD0F4CBE7
 * crc_dir_log=0x25D1E526
 * crc_dir_view=0xCCBB3C3B
 * crc_dir_pic=0xF398F584
 * crc_dir_snd=0xEABBFE13
 * crc_object=0x3E5E7D8D
 * crc_words=0x6272C53E
 *
 * [tlc2]
 * name=Space Quest: The Lost Chapter 2001-02-19
 * inherits=pc_2_936
 * id=TLC
 * crc_vol_1=0xA881F808
 * crc_vol_0=0x7CCDBCBF
 * crc_dir_log=0xA2AE3551
 * crc_dir_view=0x841FE224
 * crc_dir_pic=0x5A557B4A
 * crc_dir_snd=0x25BBCA16
 * crc_object=0x059540C8
 * crc_words=0xD176CF58
 *
 * [sqtlc3]
 * name=Space Quest: The Lost Chapter v10.0 2001-07-05
 * inherits=pc_2_936
 * id=TLC
 * crc_object=0x059540C8
 * crc_words=0x73A90362
 * crc_vol_0=0x12346AA9
 * crc_vol_1=0xA29011F4
 * crc_dir_log=0x2D7335CC
 * crc_dir_pic=0x017FF22F
 * crc_dir_view=0x1954A2FD
 * crc_dir_snd=0x0766AEDA
 *
 */

  /*
   * AGI samples/templates
   */

  { 2, 0x1f3f, 0x3fab3, 0x10be, 0x0000, 1,
    "AGI Studio tutorial game" },
  { 2, 0x4389, 0x4020c, 0x2f60, 0x0000, 1,
    "AGI Template game (1.11)" },
  { 2, 0xbb46, 0x41ccf, 0x0d77, 0x0000, 1,
    "CC's AGI Template game (0.1)" },
  { 2, 0x6dfa, 0x41ae6, 0xb5e2, 0x0000, 1,
    "CC's AGI Template game (0.1+PushObj)" },
  { 2, 0x25b4, 0x41dbc, 0xcd56, 0x0000, 1,
    "CC's AGI Template game (0.1-fixed)" },
  { 2, 0x8fb6, 0x41a61, 0xf9d3, 0x0000, 1,
    "CC's AGI Template game (0.1+mouse)" },
  { 2, 0x995d, 0x47bdb, 0x375c, 0x0000, 1,
    "AGI climb tree example (1.0)" },
  { 2, 0x8bbe, 0x41bf1, 0x769f, 0x0000, 1,
    "AGI platform example (0.1)" },

  { 2, 0x5049, 0x40ff3, 0x20ff, 0x0000, 1,
    "AGI256 demo" },
  { 2, 0xbdcc, 0x40790, 0x6940, 0x0000, 1,
    "AGI256-2 demo" },

  { 2, 0xd383, 0x40f31, 0x2d58, 0x0000, 1,
    "AGImouse 0.6 demo 1" },
  { 2, 0xab76, 0x40d74, 0x5853, 0x0000, 1,
    "AGImouse 0.6 demo 2" },
  { 2, 0x1452, 0x3f2f7, 0x78a3, 0x0000, 1,
    "AGImouse 0.7 demo" },
  { 2, 0x9f9f, 0x3f744, 0x4c2b, 0x0000, 1,
    "AGImouse 1.0 demo" },
  { 2, 0x46f1, 0x3f74f, 0xdfa5, 0x0000, 1,
    "AGImouse 1.1 demo" },
  { 2, 0x72dd, 0x7fd0e, 0x84b0, 0x0000, 1,
    "AGImouse 1.1 demo (VDM)" },

  { 2, 0x86c2, 0x40218, 0xd7c8, 0x0000, 1,
    "Animation Help demo (MA)" },
  { 2, 0x6adc, 0x12609, 0x7857, 0x0000, 1,
    "Sarien Demo (JTA)" },
  { 2, 0xa3a4, 0x42922, 0xa8d3, 0x0000, 1,
    "Two player example game (EL)" },

  /*
   * AGI games/demos (english)
   */

  { 2, 0x25bd, 0x5a434, 0xdaa6, 0x0000, 1,
    "Acidopolis (1.0) [demo] [A]" },
  { 2, 0x7ce4, 0x609ce, 0x7e32, 0x0000, 1,
    "Acidopolis (1.0) [demo] [B]" },
  { 2, 0xb39d, 0x77d51, 0xb1cb, 0x0000, 1,
    "Agent-0055 (1.0)" },
  { 2, 0x3631, 0x72367, 0xdbcf, 0x0000, 1,
    "Agent 06 vs. The Super Nazi [demo] [A]" },
  { 2, 0xc33a, 0x73639, 0x5270, 0x0000, 1,
    "Agent 06 vs. The Super Nazi [demo] [B]" },
  { 2, 0xfac1, 0x40c6f, 0x9cd1, 0x0000, 1,
    "Agent Quest" },
  { 2, 0xbab1, 0x185a6, 0xbd6d, 0x0000, 1,
    "AGI Piano [demo]" },
  { 2, 0x0480, 0x521c1, 0x2ed6, 0x0000, 1,
    "AGI Quest I: The Computer Game (1.46)" },
  { 2, 0x7a93, 0x85b3a, 0x8778, 0x0000, 1,
    "Al Pond I: Al lives forever (1.0)" },
  { 2, 0x2944, 0x89e9c, 0x24b6, 0x0000, 1,
    "Al Pond I: Al lives forever (1.1) [A]" },
  { 2, 0x203b, 0x89dbb, 0x15f0, 0x0000, 1,
    "Al Pond I: Al lives forever (1.1) [B]" },
  { 2, 0x9050, 0x892c7, 0x4110, 0x0000, 1,
    "Al Pond I: Al lives forever (1.1/clean)" },
  { 2, 0x466f, 0x6f20c, 0xf4cc, 0x0000, 1,
    "Al Pond: On Holiday (1.0)" },
  { 2, 0x2ed8, 0x705e3, 0x9d9e, 0x0000, 1,
    "Al Pond: On Holiday (1.1)" },
  { 2, 0xc32c, 0x49f7d, 0xf601, 0x0000, 1,
    "Apocalyptic Quest (0.03) [teaser] [A]" },
  { 2, 0xb4d3, 0x4a06f, 0xcd68, 0x0000, 1,
    "Apocalyptic Quest (0.03) [teaser] [B]" },
  { 2, 0xa4ac, 0x6c753, 0xfc22, 0x0000, 1,
    "Band Quest [demo] [A]" },
  { 2, 0xa52d, 0x6bb64, 0x6288, 0x0000, 1,
    "Band Quest [demo] [B]" },
  { 2, 0x775f, 0x6b835, 0xccf2, 0x0000, 1,
    "Band Quest [demo] [C]" },
  { 2, 0xbbaa, 0x45337, 0xf720, 0x0000, 1,
    "Beyond the Titanic" },
  { 2, 0xd175, 0x3f83a, 0x84c6, 0x0000, 1,
    "Botz [A]" },
  { 2, 0x30e8, 0x3f866, 0x9e42, 0x0000, 1,
    "Botz [B]" },
  { 2, 0x152b, 0x73530, 0xc139, 0x0000, 1,
    "Caitlyn's Destiny [demo] [A]" },
  { 2, 0x6a84, 0x76030, 0xc139, 0x0000, 1,
    "Caitlyn's Destiny [demo] [B]" },
  { 2, 0x2777, 0x4584b, 0x1d15, 0x0000, 1,
    "CPU-21 [demo]" },
  { 2, 0x9dc8, 0x4f5cb, 0x4018, 0x0000, 1,
    "Corby's Murder Mystery (1.0) [A]" },
  { 2, 0x4deb, 0x4f317, 0x25d9, 0x0000, 1,
    "Corby's Murder Mystery (1.0) [B]" },
  { 2, 0xfd22, 0x7b5df, 0xcfae, 0x0000, 1,
    "Dashiki [demo]" },
  { 2, 0xee9d, 0x9405b, 0x5dd8, 0x0000, 1,
    "Dashiki (256col) [demo]" },
  { 2, 0x4479, 0xbc33b, 0x5928, 0x0000, 1,
    "Date Quest (1.0)" },
  { 2, 0xe3e6, 0x89965, 0x64d5, 0x0000, 1,
    "Date Quest 2 (1.0) [demo]" },
  { 2, 0xb243, 0x91acf, 0xd831, 0x0000, 1,
    "Dave's Quest (0.07) [demo]" },
  { 2, 0xa1cc, 0x996b1, 0xb350, 0x0000, 1,
    "Dave's Quest (0.17) [demo]" },
  { 2, 0x1df7, 0x41564, 0x4abf, 0x0000, 1,
    "DG the adventure game (1.1) [demo]" },
  { 2, 0xd455, 0x4e958, 0xd8fd, 0x0000, 1,
    "DG the adventure game (1.1/mouse) [demo]" },
  { 2, 0x5026, 0x83c6f, 0x954e, 0x0000, 1,
    "Disco Nights [demo] [A]" },
  { 2, 0x02e4, 0x8326b, 0x75c0, 0x0000, 1,
    "Disco Nights [demo] [C]" },
  { 2, 0x0ade, 0x5a3c2, 0xa02f, 0x0000, 1,
    "Disco Nights [demo] [D]" },
  { 2, 0xb181, 0x666f6, 0x4f00, 0x0000, 1,
    "Dogs Quest: The Quest for the Golden Bone" },
  { 2, 0xd564, 0x6f439, 0xe460, 0x0000, 1,
    "Dr. Jummybummy's Space Adventure" },
  { 2, 0xf43c, 0x45100, 0x1723, 0x0000, 1,
    "Ed Ward I: Live Another Day [demo]" },
  { 2, 0xc58f, 0x401a5, 0x883c, 0x0000, 1,
    "Elfintard [demo]" },
  { 2, 0x7f74, 0x72154, 0x4ffa, 0x0000, 1,
    "Escape from the Desert [demo]" },
  { 2, 0x87d7, 0x43a56, 0xe458, 0x0000, 1,
    "Escape from the Salesman [A]" },
  { 2, 0x6e3b, 0x4324e, 0x1768, 0x0000, 1,
    "Escape from the Salesman [B]" },
  { 2, 0xaab2, 0x43270, 0x73db, 0x0000, 1,
    "Escape from the Salesman [C]" },
  { 2, 0xe9d5, 0x5d077, 0xb280, 0x0000, 1,
    "Escape Quest [demo]" },
  { 2, 0xbb17, 0x51b83, 0x545f, 0x0000, 1,
    "Fuck Quest" },
  { 2, 0x8f81, 0xa2f63, 0x146e, 0x0000, 1,
    "Fuck Quest 2: Romancing the Bone [demo]" },
  { 2, 0x6168, 0x42f82, 0xd177, 0x0000, 1,
    "Get Outta Space Quest" },
  { 2, 0x7a31, 0x81d9f, 0x6450, 0x0000, 1,
    "Goodman: Part One (3.41) [demo] [A]" },
  { 2, 0x6b69, 0x81ed0, 0xa1e1, 0x0000, 1,
    "Goodman: Part One (3.41) [demo] [B]" },
  { 2, 0x75ed, 0x8094e, 0xbb89, 0x0000, 1,
    "Goodman: Part One (4.0) [demo]" },
  { 2, 0x3af3, 0x80882, 0x85ca, 0x0000, 1,
    "Goodman: Part One (4.0T) [demo]" },
  { 2, 0x0cf6, 0x45cdf, 0x0a4f, 0x0000, 1,
    "Go West, Young Hippie [demo]" },
  { 2, 0xfbd6, 0x14c96, 0x08a0, 0x0000, 1,
    "Hangman" },
  { 2, 0x0c8a, 0x638d4, 0x6daf, 0x0000, 1,
    "Hank's Quest 1: Victim of Society (1.0)" },
  { 2, 0x0c21, 0x6411b, 0x542a, 0x0000, 1,
    "Hank's Quest 1: Victim of Society (1.1)" },
  { 2, 0xf7a1, 0x41a8e, 0xaf1c, 0x0000, 1,
    "Herbao (0.01) [demo]" },
  { 2, 0x9eb2, 0x4334f, 0x314b, 0x0000, 1,
    "Herbao (0.02) [demo]" },
  { 2, 0x6f9b, 0x8b5bf, 0x6a20, 0x0000, 1,
    "Hero's Adventure [demo]" },
  { 2, 0xb4a0, 0x97eb9, 0xbe70, 0x0000, 1,
    "Hitler's Legacy (0.0004q)" },
  { 2, 0x5e9f, 0x17d6d, 0x07fd, 0x0000, 1,
    "Jack and Julia: Vampyr [demo]" },
  { 2, 0x3df6, 0x91e02, 0x953b, 0x0000, 1,
    "Jeff's Quest [demo]" },
  { 2, 0x7b68, 0x6adcd, 0x6e13, 0x0000, 1,
    "Jen's Quest (0.1) [demo]" },
  { 2, 0xf7fb, 0x837a7, 0x0477, 0x0000, 1,
    "Jen's Quest (0.2) [demo]" },
  { 2, 0x3f3c, 0x43dbb, 0x6faf, 0x0000, 1,
    "Jiggy Jiggy Uh! Uh! [A]" },
  { 2, 0x00fb, 0x436a2, 0xfd65, 0x0000, 1,
    "Jiggy Jiggy Uh! Uh! [B]" },
  { 2, 0xa7a6, 0xab9a8, 0x1af3, 0x0000, 1,
    "Justin Quest (1.0) [demo]" },
  { 2, 0xd0be, 0x547bb, 0xcbb7, 0x0000, 1,
    "Lasse Holm: The Quest for Revenge (1.0)" },
  { 2, 0xc629, 0x8b24e, 0x4e3d, 0x0000, 1,
    "Lawman for Hire [demo]" },
  { 2, 0xf219, 0xaafb4, 0x4fc5, 0x0000, 1,
    "Lefty: Goes on Vacation [demo] [A]" },
  { 2, 0xf823, 0xac44c, 0x4fc5, 0x0000, 1,
    "Lefty: Goes on Vacation [demo] [B]" },
  { 2, 0x220e, 0x9f554, 0x5dd3, 0x0000, 1,
    "Lefty: Goes on Vacation [A]" },
  { 2, 0x291e, 0x9fab6, 0x19b0, 0x0000, 1,
    "Lefty: Goes on Vacation [B]" },
  { 2, 0xbda0, 0xa02b0, 0xf9b3, 0x0000, 1,
    "Lefty: Goes on Vacation [C]" },
  { 2, 0x5c5b, 0x7d6ca, 0x2043, 0x0000, 1,
    "Legend of Shay-Larah/PrinseQuest I [demo]" },
  { 2, 0x8511, 0x75c11, 0x4c27, 0x0000, 1,
    "Legend of Shay-Larah/PrinseQuest I (2.051) [demo]" },
  { 2, 0x75d6, 0x76104, 0xfdfe, 0x0000, 1,
    "Legend of Shay-Larah/PrinseQuest I (2.x) [demo]" },
  { 2, 0xabb5, 0x4572b, 0x5a13, 0x0000, 1,
    "Little Pirate/Piraatje (0.1) [demo]" },
  { 2, 0xae7b, 0x90e41, 0xa153, 0x0000, 1,
    "Little Pirate/Piraatje (0.6) [demo] [A]" },
  { 2, 0x66c6, 0x90e8f, 0x9f35, 0x0000, 1,
    "Little Pirate/Piraatje (0.6) [demo] [B]" },
  { 2, 0xb3de, 0x90990, 0xf72a, 0x0000, 1,
    "Little Pirate/Piraatje (0.6) [demo] [C]" },
  { 2, 0xa203, 0x4865a, 0x452d, 0x0000, 1,
    "MD Quest (0.66 beta) [demo]" },
  { 2, 0x2b35, 0x4ee64, 0x27a2, 0x0000, 1,
    "Monkey Man" },
  { 2, 0xd071, 0x46d36, 0xf3e7, 0x0000, 1,
    "Mouse Clicker (1.0) [A]" },
  { 2, 0x07aa, 0x46d89, 0xae20, 0x0000, 1,
    "Mouse Clicker (1.0) [B]" },
  { 2, 0x1134, 0x46c78, 0x5f30, 0x0000, 1,
    "Mouse Clicker (1.0) [C]" },
  { 2, 0x4c34, 0x4e58f, 0x25b6, 0x0000, 1,
    "Napalm Quest (0.2) [demo]" },
  { 2, 0x09ed, 0x77a8a, 0x6c4a, 0x0000, 1,
    "Napalm Quest (0.5) [demo]" },
  { 2, 0xe462, 0x6f9ec, 0x1c6e, 0x0000, 1,
    "Naturette (1.2)" },
  { 2, 0x1372, 0x70415, 0x2bbc, 0x0000, 1,
    "Naturette (1.3a)" },
  { 2, 0x134c, 0x4e2c2, 0x47c3, 0x0000, 1,
    "Naturette II: daughter of the moon (1.1a)" },
  { 2, 0x8b9f, 0x7a42e, 0x62cd, 0x0000, 1,
    "Naturette III: adventure in treeworld (1.0a)" },
  { 2, 0x1652, 0x45b55, 0x1bce, 0x0000, 1,
    "Nick's Quest (1.0)" },
  { 2, 0x41ea, 0x4664b, 0x5428, 0x0000, 1,
    "Open Mic Night (0.1)" },
  { 2, 0x7b00, 0x967dd, 0x0db3, 0x0000, 1,
    "Operation: RECON Teaser (1.0) [demo]" },
  { 2, 0x8b11, 0x96909, 0x4518, 0x0000, 1,
    "Operation: RECON Teaser (1.1) [demo]" },
  { 2, 0x58f6, 0x40370, 0x7873, 0x0000, 1,
    "Oyster [demo]" },
  { 2, 0x8c2c, 0x688d9, 0xb2c8, 0x0000, 1,
    "Patrick's Quest (1.05) [demo] [A]" },
  { 2, 0xb5e7, 0x68930, 0xc5de, 0x0000, 1,
    "Patrick's Quest (1.05) [demo] [B]" },
  { 2, 0x9fe1, 0x5859e, 0x4b01, 0x0000, 1,
    "Phantasmagoria" },
  { 2, 0x94cc, 0x4c051, 0x316b, 0x0000, 1,
    "Pharaoh Quest" },
  { 2, 0x5d8f, 0x41b00, 0xbb55, 0x0000, 1,
    "Pinkun Maze (0.1)" },
  { 2, 0xe43a, 0x3d45c, 0xff8a, 0x0000, 1,
    "Pirate Quest 1 [demo] [A]" },
  { 2, 0x14d6, 0x3d4e4, 0xad12, 0x0000, 1,
    "Pirate Quest 1 [demo] [B]" },
  { 2, 0x506f, 0x41f06, 0xcfe4, 0x0000, 1,
    "Pong (0.1) [demo]" },
  { 2, 0xe5a8, 0x17945, 0x4e64, 0x0000, 1,
    "Quest for Home [demo]" },
  { 2, 0x616c, 0x493b2, 0x0636, 0x0000, 1,
    "Quest for Ladies (1.1) [demo]" },
  { 2, 0x8774, 0x50179, 0xaa88, 0x0000, 1,
    "Ralph's Quest [demo]" },
  { 2, 0xc3f4, 0xaedd8, 0x1156, 0x0000, 1,
    "Residence 44 Quest (0.999) [demo]" },
  { 2, 0x261c, 0xb4d7a, 0xfc47, 0x0000, 1,
    "Residence 44 Quest (1.0a) [demo]" },
  { 2, 0x0012, 0x410d8, 0x613f, 0x0000, 1,
    "Schiller [demo]" },
  { 2, 0xef2e, 0x72688, 0xec3a, 0x0000, 1,
    "Serguei's Destiny (1.0)" },
  { 2, 0x11d4, 0x72827, 0x1007, 0x0000, 1,
    "Serguei's Destiny (1.1)" },
  { 2, 0x0b7f, 0x862d4, 0xd59a, 0x0000, 1,
    "Serguei's Destiny II (0.1) [demo]" },
  { 2, 0x2205, 0x846b3, 0x2a8a, 0x0000, 1,
    "Serguei's Destiny II (0.1.2) [demo]" },
  { 2, 0x6ad4, 0x6b266, 0x78c4, 0x0000, 1,
    "Shifty (1.0)" },
  { 2, 0x00dd, 0x525c2, 0x174c, 0x0000, 1,
    "Ship [demo]" },
  { 2, 0x09e0, 0x17599, 0xe4d9, 0x0000, 1,
    "Sliding Tiles Game (1.00)" },
  { 2, 0x6b78, 0x41b96, 0xf34b, 0x0000, 1,
    "Snowboarding Demo (1.0)" },
  { 2, 0x1ce0, 0x3deee, 0xb0eb, 0x0000, 1,
    "Solar System Tour" },
  { 2, 0x42df, 0x112b18, 0x8a38, 0x0000, 1,
    "Space Quest 0: Replicated (1.03)" },
  { 2, 0xf80d, 0x112bf9, 0x9495, 0x0000, 1,
    "Space Quest 0: Replicated (1.04)" },
  { 2, 0x095d, 0x6a7da, 0x5fe9, 0x0000, 1,
    "Space Quest: The Lost Chapter" },
  { 2, 0x09e9, 0x6f7f8, 0xcd56, 0x0000, 1,
    "Space Quest: The Lost Chapter (1.0/mouse) [A]" },
  { 2, 0x3e39, 0x6fe4d, 0x309d, 0x0000, 1,
    "Space Quest: The Lost Chapter (1.0/mouse) [B]" },
  { 2, 0x208b, 0x6e70f, 0x563a, 0x0000, 1,
    "Space Quest: The Lost Chapter (10.0)" },
  { 2, 0xa69b, 0x40d80, 0xc9e1, 0x0000, 1,
    "Space Trek (AGI Trek) [demo]" },
  { 2, 0xb00a, 0x64cb7, 0xbd82, 0x0000, 1,
    "Space Trek (1.0)" },
  { 2, 0x1b7f, 0x6596a, 0x67e1, 0x0000, 1,
    "Space Trek (1.0) [remake]" },
  { 2, 0x747b, 0x41c38, 0xe7c7, 0x0000, 1,
    "Special Delivery" },
  { 2, 0xb81d, 0x4c9dc, 0x7e3b, 0x0000, 1,
    "Speeder Bike Challenge [demo] [A]" },
  { 2, 0x7b52, 0x435ac, 0xea77, 0x0000, 1,
    "Speeder Bike Challenge [demo] [B]" },
  { 2, 0xfb91, 0x9f7c1, 0x4af6, 0x0000, 1,
    "Star Commander I: The Escape (1.0)" },
  { 2, 0xcd6b, 0x448cf, 0xe63e, 0x0000, 1,
    "Street Quest [demo]" },
  { 2, 0x836d, 0x58549, 0x6772, 0x0000, 1,
    "Test Quest" },
  { 2, 0x2c3d, 0x7466f, 0xb27b, 0x0000, 1,
    "Tex McPhilip I: Quest for the Papacy" },
  { 2, 0xd0f6, 0x9e400, 0x9388, 0x0000, 1,
    "Tex McPhilip II: Road to Divinity (1.5) [A]" },
  { 2, 0x8bc2, 0x9e996, 0x45c7, 0x0000, 1,
    "Tex McPhilip II: Road to Divinity (1.5) [B]" },
  { 2, 0x48fd, 0xaf761, 0x857d, 0x0000, 1,
    "The 13th Disciple (1.00) [demo] [A]" },
  { 2, 0x5a35, 0xae513, 0xfa0b, 0x0000, 1,
    "The 13th Disciple (1.00) [demo] [B]" },
  { 2, 0x92f2, 0x8f52c, 0x0e64, 0x0000, 1,
    "The Adventures of a Crazed Hermit [A]" },
  { 2, 0x9d5a, 0x8f4f1, 0xd41b, 0x0000, 1,
    "The Adventures of a Crazed Hermit [B]" },
  { 2, 0x8e3a, 0x7e26e, 0x866f, 0x0000, 1,
    "The Grateful Dead Game [A]" },
  { 2, 0x8fa6, 0x7dd5c, 0xd65e, 0x0000, 1,
    "The Grateful Dead Game [B]" },
  { 2, 0x8665, 0x40299, 0xfcb0, 0x0000, 1,
    "The Legend of Zelda: The Fungus of Time (1.0) [demo]" },
  { 2, 0x84e1, 0x6b139, 0x2697, 0x0000, 1,
    "The Legendary Harry Soupsmith (0.04) [demo] [A]" },
  { 2, 0x0866, 0x5a45f, 0xb7c6, 0x0000, 1,
    "The Legendary Harry Soupsmith (0.04) [demo] [B]" },
  { 2, 0xf22b, 0x5a4e1, 0x2134, 0x0000, 1,
    "The Legendary Harry Soupsmith (0.04) [demo] [B/rebuilt]" },
  { 2, 0xbfe7, 0x7e495, 0xb9f0, 0x0000, 1,
    "The Legendary Harry Soupsmith (0.05) [demo]" },
  { 2, 0x3bf1, 0x56278, 0x22d3, 0x0000, 1,
    "The Lost Planet (0.0001b) [demo]" },
  { 2, 0xdd63, 0x98c91, 0xf382, 0x0000, 1,
    "The Lost Planet (0.9) [demo]" },
  { 2, 0x3f1c, 0xee453, 0xfe6f, 0x0000, 1,
    "The Lost Planet (1.0) [demo]" },
  { 2, 0x201e, 0x97ec6, 0xe759, 0x0000, 1,
    "The New Adventures of Roger Wilco (1.00)" },
  { 2, 0xc411, 0x7d473, 0x9558, 0x0000, 1,
    "The Ruby Cast (0.2) [demo]" },
  { 2, 0x6a4c, 0x92a89, 0xdbd1, 0x0000, 1,
    "The Search for Tolbaga" },
  { 2, 0x227e, 0x458da, 0x7242, 0x0000, 1,
    "The Shadow Plan [demo]" },
  { 2, 0xb90f, 0x76ed8, 0xad8d, 0x0000, 1,
    "The Sorceror's Appraisal" },
  { 2, 0xaff5, 0x62d16, 0x0777, 0x0000, 1,
    "The Tales of Boromir (0.1 beta) [demo]" },
  { 2, 0x7c0c, 0x5f6c2, 0xb208, 0x0000, 1,
    "Time Quest (D0.1) [demo]" },
  /*
   * NAGI lists this as "Tutorial Game"
   */
  { 2, 0xe3bf, 0x620f6, 0x1b33, 0x0000, 1,
    "Time Quest (D0.2) [demo]" },
  { 2, 0xe76b, 0xc506a, 0x2b61, 0x0000, 1,
    "Tonight the Shrieking Corpses Bleed (0.10) [demo]" },
  { 2, 0x3237, 0xc46da, 0xa373, 0x0000, 1,
    "Tonight the Shrieking Corpses Bleed (0.11) [demo]" },
  { 2, 0xf4c7, 0x426b9, 0x0a49, 0x0000, 1,
    "Tryout (0.1) [demo]" },
  { 2, 0xd997, 0x50042, 0x01ab, 0x0000, 1,
    "Turks' Quest (Reno climbs tree) [demo]" },
  { 2, 0xcf53, 0x4982d, 0x3dbc, 0x0000, 1,
    "Turks' Quest: Heir to the Planet [A]" },
  { 2, 0x628e, 0x7d7d1, 0xcaf2, 0x0000, 1,
    "Turks' Quest: Heir to the Planet [B]" },
  { 2, 0xbf74, 0x8241d, 0xff4d, 0x0000, 1,
    "Turks' Quest: Heir to the Planet [C]" },
  { 2, 0x4027, 0x7e401, 0x4292, 0x0000, 1,
    "URI Quest (0.173) [A]" },
  { 2, 0x1500, 0x7cf37, 0xed1f, 0x0000, 1,
    "URI Quest (0.173) [B]" },
  { 2, 0x9275, 0x5d9c6, 0x65cd, 0x0000, 1,
    "V - The Graphic Adventure (0.10 beta) [demo] [A]" },
  { 2, 0xaa71, 0x5927e, 0x561a, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.0)" },
  { 2, 0x717b, 0x511ad, 0xfc45, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.2) [A]" },
  { 2, 0x096d, 0x72ad8, 0x3aef, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.2) [B]" },
  { 2, 0xadb5, 0x71ec5, 0xd022, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.2) [C]" },
  { 2, 0x80e5, 0xa3395, 0x79ea, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.2) [D]" },
  { 2, 0xc494, 0xa3489, 0xadf2, 0x0000, 1,
    "Voodoo Girl: Queen of the Darned (1.2) [E]" },
  { 2, 0x7fbf, 0x8d2ec, 0x7c80, 0x0000, 1,
    "Wizaro (0.1)" },
  { 2, 0x18c3, 0x6dacc, 0xa50c, 0x0000, 1,
    "WOK [demo]" },

  /*
   * AGI games/demos (non-english)
   */

  { 2, 0x2ec4, 0x80081, 0xa316, 0x0000, 1,
    "Abrah, l'orphelin de l'espace (1.0 french)" },
  { 2, 0xc563, 0x7f574, 0xce08, 0x0000, 1,
    "Abrah, l'orphelin de l'espace (1.2 french)" },
  { 2, 0x2bdd, 0x74b86, 0xc6a4, 0x0000, 1,
    "Coco Coq dans la base de Grostesteing (1.0.1 french)" },
  { 2, 0x63e3, 0x74c0e, 0x15cb, 0x0000, 1,
    "Coco Coq dans la base de Grostesteing (1.0.2 french)" },
  { 2, 0x2ab3, 0x40ade, 0xd813, 0x0000, 1,
    "DG the adventure game (1.0 french) [demo]" },
  { 2, 0x48b8, 0x40a6e, 0x9fe8, 0x0000, 1,
    "DG the adventure game (1.1 french) [demo]" },
  { 2, 0x5dcb, 0x4ec4c, 0xbf06, 0x0000, 1,
    "DG the adventure game (1.1/mouse french) [demo]" },
  { 2, 0xdb09, 0x5501a, 0x124e, 0x0000, 1,
    "Groza (russian) [AGDS sample]" },
  { 2, 0x68c2, 0x6028e, 0x3257, 0x0000, 1,
    "Hank's Quest 1: Slachtoffer van het gebeuren (1.0 dutch)" },
  { 2, 0xc646, 0x785c4, 0x6a04, 0x0000, 1,
    "Jolimie le village maudit (0.6 french)" },
  { 2, 0xae3a, 0x71c62, 0x2bed, 0x0000, 1,
    "Jolimie le village maudit (1.0 french)" },
  { 2, 0xfd78, 0x7217e, 0x3103, 0x0000, 1,
    "Jolimie le village maudit (1.1 french)" },
  { 2, 0xa8bb, 0x50aff, 0x2567, 0x0000, 1,
    "Joulumaa (0.05 finnish) [demo]" },
  { 2, 0x3470, 0x92483, 0x9963, 0x0000, 1,
    "Les Inseparables (0.1 french) [demo]" },
  { 2, 0xb577, 0x91982, 0x24e5, 0x0000, 1,
    "Les Inseparables (0.2 french) [demo]" },
  { 2, 0x18b9, 0x7d4cf, 0xd76a, 0x0000, 1,
    "Les Inseparables (1.0 french)" },
  { 2, 0x94b8, 0x8503e, 0x190a, 0x0000, 1,
    "Naturette (1.2 french)" },
  { 2, 0x720b, 0x6ebe8, 0x4e5b, 0x0000, 1,
    "Naturette (1.3 french)" },
  { 2, 0x0921, 0xb6973, 0x9185, 0x0000, 1,
    "Residence 44 Quest (0.999 dutch) [demo]" },

/******************** FANFIC AGIv3 ********************/

  { 3, 0x9910, 0xd3343, 0x59c0, 0x0000, 1,
    "V - The Graphic Adventure (0.10 beta) [demo] [B]" },
  /*
   * guess I've missed some relaeses of demo2 here...
   */
  { 3, 0xbb54, 0xdccd4, 0xc154, 0x0000, 1,
    "V - The Graphic Adventure (1.0) [demo 2] [A]" },
  { 3, 0x9b66, 0xdb8cd, 0x3fae, 0x0000, 1,
    "V - The Graphic Adventure (1.0) [demo 2] [A/rebuilt]" },
  { 3, 0x649d, 0xdd9a4, 0xd286, 0x0000, 1,
    "V - The Graphic Adventure (1.0) [demo 2] [B]" },
  { 3, 0xb8e7, 0xde2a9, 0x6c6c, 0x0000, 1,
    "V - The Graphic Adventure (1.0) [demo 2] [C]" },

  { 0, 0x0000, 0x00000, 0x0000, 0x0000, 0,
    "*" }
};

/*
 * Why is there no GNU Indent option to *properly* format such tables
 * within structs without wasting tons of space? Beats me...
 */
/* *INDENT-ON* */




void
data_usage (void)
{
  type16 i = 0;
  type16 counti = 0, count0 = 0, count1 = 0, count2 = 0;

  counti = (sizeof (int_table) / sizeof (struct intbase)) - 1;
  while (version_table[i].agi_version != 0)
    {
      if (version_table[i].status == 0)
	count0++;
      if (version_table[i].status == 1)
	count1++;
      if (version_table[i].status == 2)
	count2++;
      i++;
    }
  fprintf (stderr, "using database " BASEVERSION " (" BASEDATE "):\n");
  fprintf (stderr, "Detects AGI interpreter and game version.\n");
  fprintf (stderr,
	 "Current version detects %d interpreters and %d original games.\n",
	   counti, count0);
  fprintf (stderr,
	   "Also detects %d broken originals and %d fan-made AGI games.\n",
	   count2, count1);
}

void
data_info (void)
{
  fprintf (stdout, "using database " BASEVERSION " (" BASEDATE "):\n\n");
}

void
data_list (type8 listype)
{
/*
 * listypes:  1  -ld  == status=0
 *            2  -ld2 == status=0 & AGIv2
 *            3  -ld3 == status=0 & AGIv3
 *           11  -lf  == status=1
 *           12  -bd  == status=2
 *           13  -md  == status=3
 */
  type16 i = 0, j, count = 1;

  fprintf (stdout, "List of ");

  if (listype == 11)
    fprintf (stdout, "detected fan-made");
  else if (listype == 12)
    fprintf (stdout, "broken");
  else if (listype == 13)
    fprintf (stdout, "urgently wanted");
  else
    fprintf (stdout, "fully detected");

  fprintf (stdout, " ");

  if (listype == 2)
    fprintf (stdout, "AGIv2");
  else if (listype == 3)
    fprintf (stdout, "AGIv3");
  else
    fprintf (stdout, "AGIv2/v3");

  fprintf (stdout, " games:\n");

  while (version_table[i].agi_version != 0)
    {
      if (((listype == 1) && (version_table[i].status == 0))
	  || ((listype == 2) && (version_table[i].status == 0)
	      && (version_table[i].agi_version == 2))
	  || ((listype == 3) && (version_table[i].status == 0)
	      && (version_table[i].agi_version == 3))
	  || ((listype == 11) && (version_table[i].status == 1))
	  || ((listype == 12) && (version_table[i].status == 2))
	  || ((listype == 13) && (version_table[i].status == 3)))
	{
#ifdef DEBUG
	  fprintf (stdout, " -");
#else
	  fprintf (stdout, "%3d.", count);
#endif
	  fprintf (stdout, " %s", version_table[i].game);
	  count++;

	  if (((listype < 4) || (listype == 12))
	      && (version_table[i].interp_match != 0))
	    {
	      j = 0;
	      while ((int_table[j].int_id !=
		      version_table[i].interp_match)
		     && (int_table[j].int_id != 0))
		j++;
	      if (int_table[j].int_id != 0)
		fprintf (stdout, " [Interpreter %s]", int_table[j].interp);
	    }
	  fprintf (stdout, "\n");
	}

      i++;
    }

  if (listype == 13)
    fprintf (stdout,
	     "\n"
    "If you happen to have any of these game versions, please mail them to\n"
	     "<agi@pdd.de>.\n");
}
